==> qthello_0.7.2.tar.gz: qthello-0.7.2/src/qthello_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk_UA">
<context>
    <name>CentralWidget</name>
    <message>
        <location filename="centralwidget.cpp" line="103"/>
        <source>Error!!
Unable to start the game server: %1.</source>
        <translation>Помилка!!
Неможливо запустити сервер: %1.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="179"/>
        <source>Warning!
Wait answer from client.</source>
        <translation>Увага!
Очiкування вiвдповiдi вiд клiєнта.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="182"/>
        <source>Warning!
Client is paused.</source>
        <translation>Увага!
Клiєнт призупинено.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="185"/>
        <source>Warning!
Server is paused.</source>
        <translation>Увага!
Сервер призупинено.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="189"/>
        <source>Warning!
Wait answer from server.</source>
        <translation>Увага!
Очiкування вiвдповiдi вiд сервера.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="197"/>
        <source>Warning!
It&apos;s White player turn now.</source>
        <translation>Увага!
Зараз ходять бiлi.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="202"/>
        <source>Warning!
It&apos;s Black player turn now.</source>
        <translation>Увага!
Зараз ходять чорнi.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="216"/>
        <source>White</source>
        <translation>Бiлi</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="216"/>
        <source>Black</source>
        <translation>Чорнi</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="218"/>
        <source>%1 can&apos;t move. %2 turn.</source>
        <translation>%1 не можуть ходити. %2 ходять.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="253"/>
        <source>Warning!
The host was not found.</source>
        <translation>Увага! Хост не знайдено.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="256"/>
        <source>Warning!
The connection was refused by the peer.</source>
        <translation>Увага! З&apos;єднання вiдхилено протилежною стороною.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="259"/>
        <source>The following error occurred: %1.</source>
        <translation>Трапилась помилка: %1.</translation>
    </message>
</context>
<context>
    <name>ClientDialog</name>
    <message>
        <location filename="clientdialog.cpp" line="18"/>
        <source>Waiting black player (server)</source>
        <translation>Очiкування чорного гравця (сервера)</translation>
    </message>
    <message>
        <location filename="clientdialog.cpp" line="20"/>
        <source>Enter IP and port of server:</source>
        <translation>Введiть IP адресу та порт серверу:</translation>
    </message>
    <message>
        <location filename="clientdialog.cpp" line="24"/>
        <source>IP:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="clientdialog.cpp" line="29"/>
        <source>Port:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="clientdialog.cpp" line="38"/>
        <source>C&amp;onnect</source>
        <translation>&amp;З&apos;єднати</translation>
    </message>
    <message>
        <location filename="clientdialog.cpp" line="42"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Вiдмiнити</translation>
    </message>
</context>
<context>
    <name>InfoPanel</name>
    <message>
        <location filename="infopanel.cpp" line="38"/>
        <source>Black turn</source>
        <translation>Чорнi ходять</translation>
    </message>
    <message>
        <location filename="infopanel.cpp" line="52"/>
        <source>White</source>
        <translation>Бiлi</translation>
    </message>
    <message>
        <location filename="infopanel.cpp" line="52"/>
        <source>Black</source>
        <translation>Чорнi</translation>
    </message>
    <message>
        <location filename="infopanel.cpp" line="54"/>
        <source>%1 turn</source>
        <translation>%1 ходять</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="17"/>
        <source>Qthello</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="38"/>
        <source>&amp;Game</source>
        <translation>&amp;Гра</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="39"/>
        <source>&amp;New game</source>
        <translation>&amp;Нова гра</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="44"/>
        <source>E&amp;xit</source>
        <translation>&amp;Вихiд</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="48"/>
        <source>&amp;Help</source>
        <translation>&amp;Допомога</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="49"/>
        <source>&amp;About...</source>
        <translation>&amp;Про програму...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="61"/>
        <source>Game over!
 White player %1; Black player %2.</source>
        <translation>Гру завершено! Бiлi %1; Чорнi %2.</translation>
    </message>
    <message>
        <source>White</source>
        <translation type="obsolete">Бiлi</translation>
    </message>
    <message>
        <source>Black</source>
        <translation type="obsolete">Чорнi</translation>
    </message>
    <message>
        <source>%1 can&apos;t move. %2 turn.</source>
        <translation type="obsolete">%1 не можуть ходити. %2 ходять.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="73"/>
        <source>About Qthello</source>
        <translation>Про Отелло</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="73"/>
        <source>Othello/Reversi game

General programming - (c) 2010 Vadim Khohlov &lt;xvadima@ukr.net&gt;

Images - GPE-Othello project (c) 2007 Joseph J. McCarthy &lt;mccarthy@granular.che.pitt.edu&gt;

AI Engine - KReversi project (c) 1997-2000, Mario Weilguni
(c) 2004-2006, Inge Wallin
(c) 2006, Dmitry Suzdalev</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ModePanel</name>
    <message>
        <location filename="modepanel.cpp" line="15"/>
        <source>Mode: </source>
        <translation>Режим:</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="17"/>
        <source>AI level: </source>
        <translation>Рiвень ШI:</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="21"/>
        <source>Human vs human</source>
        <translation>Людина-людина</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="22"/>
        <source>Human vs computer</source>
        <translation>Людина-комп.</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="23"/>
        <source>Computer vs human</source>
        <translation>Комп.-людина</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="24"/>
        <source>Net (server)</source>
        <translation>Net (сервер)</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="25"/>
        <source>Net (client)</source>
        <translation>Net (клiєнт)</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="37"/>
        <source>Expert</source>
        <translation>Експерт</translation>
    </message>
    <message>
        <source>Very easy</source>
        <translation type="obsolete">Дуже простий</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="31"/>
        <source>Easy</source>
        <translation>Простий</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="32"/>
        <source>Medium</source>
        <translation>Середнiй</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="33"/>
        <source>Hard</source>
        <translation>Важкий</translation>
    </message>
    <message>
        <source>Very hard</source>
        <translation type="obsolete">Дуже важкий</translation>
    </message>
    <message>
        <source>Extremely hard</source>
        <translation type="obsolete">Надважкий</translation>
    </message>
    <message>
        <source>Impossible</source>
        <translation type="obsolete">Неможливий</translation>
    </message>
</context>
<context>
    <name>ServerDialog</name>
    <message>
        <location filename="serverdialog.cpp" line="24"/>
        <source>Waiting white player (client)</source>
        <translation>Очiкування бiлого гравця (клiєнта)</translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="26"/>
        <source>The server is running on:</source>
        <translation>Сервер запущено на:</translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="30"/>
        <source>IP:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="50"/>
        <source>Port:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="52"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="64"/>
        <source>&amp;New game</source>
        <translation>&amp;Нова гра</translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="68"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Вiдмiнити</translation>
    </message>
</context>
</TS>

==> qthello_0.8-1.tar.gz: qthello-0.8/src/qthello_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk_UA">
<context>
    <name>CentralWidget</name>
    <message>
        <location filename="centralwidget.cpp" line="134"/>
        <source>Error!!
Unable to start the game server: %1.</source>
        <translation>Помилка!!
Неможливо запустити сервер: %1.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="210"/>
        <source>Warning!
Wait answer from client.</source>
        <translation>Увага!
Очiкування вiвдповiдi вiд клiєнта.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="213"/>
        <source>Warning!
Client is paused.</source>
        <translation>Увага!
Клiєнт призупинено.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="216"/>
        <source>Warning!
Server is paused.</source>
        <translation>Увага!
Сервер призупинено.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="220"/>
        <source>Warning!
Wait answer from server.</source>
        <translation>Увага!
Очiкування вiвдповiдi вiд сервера.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="228"/>
        <source>Warning!
It&apos;s White player turn now.</source>
        <translation>Увага!
Зараз ходять бiлi.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="233"/>
        <source>Warning!
It&apos;s Black player turn now.</source>
        <translation>Увага!
Зараз ходять чорнi.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="247"/>
        <source>White</source>
        <translation>Бiлi</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="247"/>
        <source>Black</source>
        <translation>Чорнi</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="249"/>
        <source>%1 can&apos;t move. %2 turn.</source>
        <translation>%1 не можуть ходити. %2 ходять.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="284"/>
        <source>Warning!
The host was not found.</source>
        <translation>Увага! Хост не знайдено.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="287"/>
        <source>Warning!
The connection was refused by the peer.</source>
        <translation>Увага! З&apos;єднання вiдхилено протилежною стороною.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="290"/>
        <source>The following error occurred: %1.</source>
        <translation>Трапилась помилка: %1.</translation>
    </message>
    <message>
        <location filename="centralwidget.cpp" line="310"/>
        <source>Game over!
 White player %1; Black player %2.</source>
        <translation>Гру завершено! Бiлi %1; Чорнi %2.</translation>
    </message>
</context>
<context>
    <name>ClientDialog</name>
    <message>
        <location filename="clientdialog.cpp" line="18"/>
        <source>Waiting black player (server)</source>
        <translation>Очiкування чорного гравця (сервера)</translation>
    </message>
    <message>
        <location filename="clientdialog.cpp" line="20"/>
        <source>Enter IP and port of server:</source>
        <translation>Введiть IP адресу та порт серверу:</translation>
    </message>
    <message>
        <location filename="clientdialog.cpp" line="24"/>
        <source>IP:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="clientdialog.cpp" line="29"/>
        <source>Port:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="clientdialog.cpp" line="38"/>
        <source>C&amp;onnect</source>
        <translation>&amp;З&apos;єднати</translation>
    </message>
    <message>
        <location filename="clientdialog.cpp" line="42"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Вiдмiнити</translation>
    </message>
</context>
<context>
    <name>InfoPanel</name>
    <message>
        <location filename="infopanel.cpp" line="38"/>
        <source>Black turn</source>
        <translation>Чорнi ходять</translation>
    </message>
    <message>
        <location filename="infopanel.cpp" line="52"/>
        <source>White</source>
        <translation>Бiлi</translation>
    </message>
    <message>
        <location filename="infopanel.cpp" line="52"/>
        <source>Black</source>
        <translation>Чорнi</translation>
    </message>
    <message>
        <location filename="infopanel.cpp" line="54"/>
        <source>%1 turn</source>
        <translation>%1 ходять</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="20"/>
        <source>Qthello</source>
        <translation></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="40"/>
        <source>&amp;Game</source>
        <translation>&amp;Гра</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="41"/>
        <source>&amp;New game</source>
        <translation>&amp;Нова гра</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="46"/>
        <source>E&amp;xit</source>
        <translation>&amp;Вихiд</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="50"/>
        <source>&amp;Options</source>
        <translation>&amp;Параметри</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="51"/>
        <source>&amp;Options...</source>
        <translation>&amp;Параметри...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="54"/>
        <source>&amp;Help</source>
        <translation>&amp;Допомога</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="55"/>
        <source>&amp;About...</source>
        <translation>&amp;Про програму...</translation>
    </message>
    <message>
        <source>Game over!
 White player %1; Black player %2.</source>
        <translation type="obsolete">Гру завершено! Бiлi %1; Чорнi %2.</translation>
    </message>
    <message>
        <source>White</source>
        <translation type="obsolete">Бiлi</translation>
    </message>
    <message>
        <source>Black</source>
        <translation type="obsolete">Чорнi</translation>
    </message>
    <message>
        <source>%1 can&apos;t move. %2 turn.</source>
        <translation type="obsolete">%1 не можуть ходити. %2 ходять.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="71"/>
        <source>About Qthello</source>
        <translation>Про Отелло</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="71"/>
        <source>Othello/Reversi game

General programming - (c) 2010 Vadim Khohlov &lt;xvadima@ukr.net&gt;

Images - GPE-Othello project (c) 2007 Joseph J. McCarthy &lt;mccarthy@granular.che.pitt.edu&gt;

AI Engine - KReversi project (c) 1997-2000, Mario Weilguni
(c) 2004-2006, Inge Wallin
(c) 2006, Dmitry Suzdalev</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>ModePanel</name>
    <message>
        <location filename="modepanel.cpp" line="15"/>
        <source>Mode: </source>
        <translation>Режим:</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="17"/>
        <source>AI level: </source>
        <translation>Рiвень ШI:</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="21"/>
        <source>Human vs human</source>
        <translation>Людина-людина</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="22"/>
        <source>Human vs computer</source>
        <translation>Людина-комп.</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="23"/>
        <source>Computer vs human</source>
        <translation>Комп.-людина</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="24"/>
        <source>Net (server)</source>
        <translation>Net (сервер)</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="25"/>
        <source>Net (client)</source>
        <translation>Net (клiєнт)</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="33"/>
        <source>Expert</source>
        <translation>Експерт</translation>
    </message>
    <message>
        <source>Very easy</source>
        <translation type="obsolete">Дуже простий</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="30"/>
        <source>Easy</source>
        <translation>Простий</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="31"/>
        <source>Medium</source>
        <translation>Середнiй</translation>
    </message>
    <message>
        <location filename="modepanel.cpp" line="32"/>
        <source>Hard</source>
        <translation>Важкий</translation>
    </message>
    <message>
        <source>Very hard</source>
        <translation type="obsolete">Дуже важкий</translation>
    </message>
    <message>
        <source>Extremely hard</source>
        <translation type="obsolete">Надважкий</translation>
    </message>
    <message>
        <source>Impossible</source>
        <translation type="obsolete">Неможливий</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="optionsdialog.cpp" line="17"/>
        <source>Animation speed:</source>
        <translation>Швiдкисть анiмацiї:</translation>
    </message>
    <message>
        <location filename="optionsdialog.cpp" line="20"/>
        <source>No animation</source>
        <translation>Без анiмацiї</translation>
    </message>
    <message>
        <location filename="optionsdialog.cpp" line="21"/>
        <source>Slow</source>
        <translation>Повiльно</translation>
    </message>
    <message>
        <location filename="optionsdialog.cpp" line="22"/>
        <source>Medium</source>
        <translation>Середня</translation>
    </message>
    <message>
        <location filename="optionsdialog.cpp" line="23"/>
        <source>Fast</source>
        <translation>Швидко</translation>
    </message>
    <message>
        <location filename="optionsdialog.cpp" line="27"/>
        <source>&amp;Save mode on exit</source>
        <translation>&amp;Зберiгати режим при виходi</translation>
    </message>
    <message>
        <location filename="optionsdialog.cpp" line="31"/>
        <source>Start new game automatically</source>
        <translation>Автоматично статувати нову гру</translation>
    </message>
</context>
<context>
    <name>ScorePanel</name>
    <message>
        <location filename="scorepanel.cpp" line="10"/>
        <source>Won</source>
        <translation>Перемог</translation>
    </message>
    <message>
        <location filename="scorepanel.cpp" line="12"/>
        <source>Lost</source>
        <translation>Поразок</translation>
    </message>
    <message>
        <location filename="scorepanel.cpp" line="14"/>
        <source>Drawn</source>
        <translation>Нiчiїх</translation>
    </message>
</context>
<context>
    <name>ServerDialog</name>
    <message>
        <location filename="serverdialog.cpp" line="24"/>
        <source>Waiting white player (client)</source>
        <translation>Очiкування бiлого гравця (клiєнта)</translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="26"/>
        <source>The server is running on:</source>
        <translation>Сервер запущено на:</translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="30"/>
        <source>IP:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="50"/>
        <source>Port:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="52"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="64"/>
        <source>&amp;New game</source>
        <translation>&amp;Нова гра</translation>
    </message>
    <message>
        <location filename="serverdialog.cpp" line="68"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Вiдмiнити</translation>
    </message>
</context>
</TS>
